#!/usr/bin/python
### Burmese grapheme segmentation for Romanization
### --- onset, rhyme, and tone within a syllible are segmented
### by ******** ****, @ ****, 2016/11
### for python 2.x: tested with python 2.6 and 2.7
### for python 3.x: unichr -> chr, using the "python 3.x" lines

import sys, os, codecs
### for python 2.x
sys.stdin  = codecs.getreader('utf-8')(sys.stdin)
sys.stdout = codecs.getwriter('utf-8')(sys.stdout)
sys.stderr = codecs.getwriter('utf-8')(sys.stderr)
### for python 3.x
### sys.stdin  = codecs.getreader('utf-8')(sys.stdin.buffer)
### sys.stdout = codecs.getwriter('utf-8')(sys.stdout.buffer)
### sys.stderr = codecs.getwriter('utf-8')(sys.stderr.buffer)

WA, HA = unichr (0x103d), unichr (0x103e)
AUK, ASAT = unichr (0x1037), unichr (0x103a)
WH, HW = WA + HA, HA + WA
KT, TK = AUK + ASAT, ASAT + AUK

IND  = set ([unichr (0x1000+x) for x in range (42)]+[unichr (0x103f)])
MID  = set ([unichr (0x103b), unichr (0x103c), HA])
TONE = set ([unichr (0x1038), AUK])
VRM  = set ([ASAT])
X    = set ([unichr (0x1039), "(", ")"])

MAP  = [[IND, "i"], [MID, "m"], [TONE, "t"], [X, "x"], [VRM, "q"]]
INST = {"ii" : " @ ", "mi" : " @ ", "im" : ""}

def ort_seg (m) :
	m = "".join (m.replace (WH, HW).replace (KT, TK).split ())
	TAG, SEG = ["r" for c in m], ""
	for i in range (len (m)) : 
		for s, t in MAP : 
			if m [i] in s : TAG [i] = t; break
	TAG = "".join (TAG).replace ("iq", "rr").replace ("rq", "rr") + "i"
	for i in range (len (m)) :
		SEG += m [i]
		if TAG [i:i+2] in INST : SEG += INST [TAG [i:i+2]]
		elif TAG [i] != TAG [i+1] : SEG += " "
	return "".join (SEG).strip ()

def ort_rec (m) : 
	return "".join (m.split ()).replace (HW, WH).replace (TK, KT).replace ("@", "")

def main () :
	try :
		for m in sys.stdin :
			if len (sys.argv) > 1 and sys.argv [1] == "rec" :
				sys.stdout.write (ort_rec (m) + "\n")
			else :	sys.stdout.write (ort_seg (m) + "\n")
	except : pass

if __name__ == "__main__" : main ()
